@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -81,6 +81,7 @@ from lib.core.settings import UNICODE_ENCODING
 from lib.core.settings import ROTATING_CHARS
 from lib.core.wordlist import Wordlist
 from thirdparty.colorama.initialise import init as coloramainit
+from thirdparty.oset.pyoset import oset
 from thirdparty.pydes.pyDes import des
 from thirdparty.pydes.pyDes import CBC
 
@@ -555,37 +556,37 @@ def storeHashesToFile(attack_dict):
     if not attack_dict:
         return
 
+    items = oset()
+
+    for user, hashes in attack_dict.items():
+        for hash_ in hashes:
+            hash_ = hash_.split()[0] if hash_ and hash_.strip() else hash_
+            if hash_ and hash_ != NULL and hashRecognition(hash_):
+                item = None
+                if user and not user.startswith(DUMMY_USER_PREFIX):
+                    item = "%s:%s\n" % (user.encode(UNICODE_ENCODING), hash_.encode(UNICODE_ENCODING))
+                else:
+                    item = "%s\n" % hash_.encode(UNICODE_ENCODING)
+
+                if item and item not in items:
+                    items.add(item)
+
     if kb.storeHashesChoice is None:
         message = "do you want to store hashes to a temporary file "
         message += "for eventual further processing with other tools [y/N] "
 
         kb.storeHashesChoice = readInput(message, default='N', boolean=True)
 
-    if not kb.storeHashesChoice:
-        return
+    if items and kb.storeHashesChoice:
+        handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.HASHES, suffix=".txt")
+        os.close(handle)
 
-    handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.HASHES, suffix=".txt")
-    os.close(handle)
+        infoMsg = "writing hashes to a temporary file '%s' " % filename
+        logger.info(infoMsg)
 
-    infoMsg = "writing hashes to a temporary file '%s' " % filename
-    logger.info(infoMsg)
-
-    items = set()
-
-    with open(filename, "w+") as f:
-        for user, hashes in attack_dict.items():
-            for hash_ in hashes:
-                hash_ = hash_.split()[0] if hash_ and hash_.strip() else hash_
-                if hash_ and hash_ != NULL and hashRecognition(hash_):
-                    item = None
-                    if user and not user.startswith(DUMMY_USER_PREFIX):
-                        item = "%s:%s\n" % (user.encode(UNICODE_ENCODING), hash_.encode(UNICODE_ENCODING))
-                    else:
-                        item = "%s\n" % hash_.encode(UNICODE_ENCODING)
-
-                    if item and item not in items:
-                        f.write(item)
-                        items.add(item)
+        with open(filename, "w+") as f:
+            for item in items:
+                f.write(item)
 
 def attackCachedUsersPasswords():
     if kb.data.cachedUsersPasswords:
@@ -692,9 +693,7 @@ def hashRecognition(value):
     if isinstance(value, basestring):
         for name, regex in getPublicTypeMembers(HASH):
             # Hashes for Oracle and old MySQL look the same hence these checks
-            if isOracle and regex == HASH.MYSQL_OLD:
-                continue
-            elif isMySQL and regex == HASH.ORACLE_OLD:
+            if isOracle and regex == HASH.MYSQL_OLD or isMySQL and regex == HASH.ORACLE_OLD:
                 continue
             elif regex == HASH.CRYPT_GENERIC:
                 if any((value.lower() == value, value.upper() == value)):
@@ -711,7 +710,7 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
 
     count = 0
     rotator = 0
-    hashes = set([item[0][1] for item in attack_info])
+    hashes = set(item[0][1] for item in attack_info)
 
     wordlist = Wordlist(wordlists, proc_id, getattr(proc_count, "value", 0), custom_wordlist)
 
@@ -757,7 +756,7 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
                     if rotator >= len(ROTATING_CHARS):
                         rotator = 0
 
-                    status = 'current status: %s... %s' % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
+                    status = "current status: %s... %s" % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
 
                     if not api:
                         dataToStdout("\r[%s] [INFO] %s" % (time.strftime("%X"), status))
@@ -826,12 +825,14 @@ def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found
 
                 elif (proc_id == 0 or getattr(proc_count, "value", 0) == 1) and count % HASH_MOD_ITEM_DISPLAY == 0:
                     rotator += 1
+
                     if rotator >= len(ROTATING_CHARS):
                         rotator = 0
-                    status = 'current status: %s... %s' % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
+
+                    status = "current status: %s... %s" % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
 
                     if user and not user.startswith(DUMMY_USER_PREFIX):
-                        status += ' (user: %s)' % user
+                        status += " (user: %s)" % user
 
                     if not api:
                         dataToStdout("\r[%s] [INFO] %s" % (time.strftime("%X"), status))
