@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
 import re
 
+from lib.core.common import isDBMSVersionAtLeast
 from lib.core.common import randomStr
 from plugins.generic.syntax import Syntax as GenericSyntax
 
@@ -17,6 +18,9 @@ class Syntax(GenericSyntax):
     @staticmethod
     def escape(expression, quote=True):
         """
+        >>> from lib.core.common import Backend
+        >>> Backend.setVersion('12.10')
+        ['12.10']
         >>> Syntax.escape("SELECT 'abcdefgh' FROM foobar")
         'SELECT CHR(97)||CHR(98)||CHR(99)||CHR(100)||CHR(101)||CHR(102)||CHR(103)||CHR(104) FROM foobar'
         """
@@ -24,14 +28,17 @@ class Syntax(GenericSyntax):
         def escaper(value):
             return "||".join("CHR(%d)" % ord(_) for _ in value)
 
-        excluded = {}
-        for _ in re.findall(r"DBINFO\([^)]+\)", expression):
-            excluded[_] = randomStr()
-            expression = expression.replace(_, excluded[_])
+        retVal = expression
 
-        retVal = Syntax._escape(expression, quote, escaper)
+        if isDBMSVersionAtLeast("11.70"):
+            excluded = {}
+            for _ in re.findall(r"DBINFO\([^)]+\)", expression):
+                excluded[_] = randomStr()
+                expression = expression.replace(_, excluded[_])
 
-        for _ in excluded.items():
-            retVal = retVal.replace(_[1], _[0])
+            retVal = Syntax._escape(expression, quote, escaper)
+
+            for _ in excluded.items():
+                retVal = retVal.replace(_[1], _[0])
 
         return retVal
\ No newline at end of file
